PdfDocumentLoader class

PdfDocumentLoader is a Widget that used to load arbitrary PDF document and manages PdfDocument instance.

Inheritance

Constructors

PdfDocumentLoader({Key? key, required FutureOr<PdfDocument> doc, PdfDocumentBuilder? documentBuilder, int? pageNumber, PdfPageBuilder? pageBuilder, dynamic onError(dynamic)?})
Use one of PdfDocumentLoader.openFile, PdfDocumentLoader.openAsset, or PdfDocumentLoader.openData in normal case. If you already have PdfDocument, you can use the method.
PdfDocumentLoader.openAsset(String assetName, {Key? key, PdfDocumentBuilder? documentBuilder, int? pageNumber, PdfPageBuilder? pageBuilder, dynamic onError(dynamic)?})
Load PDF document from asset.
factory
PdfDocumentLoader.openData(Uint8List data, {Key? key, PdfDocumentBuilder? documentBuilder, int? pageNumber, PdfPageBuilder? pageBuilder, dynamic onError(dynamic)?})
Load PDF document from PDF binary data.
factory
PdfDocumentLoader.openFile(String filePath, {Key? key, PdfDocumentBuilder? documentBuilder, int? pageNumber, PdfPageBuilder? pageBuilder, dynamic onError(dynamic)?})
Load PDF document from file.
factory

Properties

doc → FutureOr<PdfDocument>
final
documentBuilder → PdfDocumentBuilder?
Function to build widget tree corresponding to PDF document.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onError → dynamic Function(dynamic)?
Error callback
final
pageBuilder → PdfPageBuilder?
Function to build page widget tree.
final
pageNumber → int?
Page number of the page to render if only one page should be shown.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → PdfDocumentLoaderState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited