PdfViewer class

A PDF viewer implementation with user interactive zooming support.

Inheritance

Constructors

PdfViewer({Key? key, required FutureOr<PdfDocument> doc, PdfViewerController? viewerController, PdfViewerParams? params, OnError? onError})
PdfViewer.openAsset(String assetPath, {Key? key, PdfViewerController? viewerController, PdfViewerParams? params, OnError? onError})
Open an asset.
factory
PdfViewer.openData(Uint8List data, {Key? key, PdfViewerController? viewerController, PdfViewerParams? params, OnError? onError})
Open PDF data on byte array.
factory
PdfViewer.openFile(String filePath, {Key? key, PdfViewerController? viewerController, PdfViewerParams? params, OnError? onError})
Open a file.
factory

Properties

doc → FutureOr<PdfDocument>
PDF document instance.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onError → OnError?
Error handler.
final
params → PdfViewerParams?
Additional parameter to configure the viewer.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
viewerController → PdfViewerController?
Controller for the viewer. If none is specified, the viewer initializes one internally.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → PdfViewerState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

openFuture<T>(Future<T> getFuture(), Future<PdfDocument> futureToDocument(T), {Key? key, PdfViewerController? viewerController, PdfViewerParams? params, OnError? onError, Widget loadingBannerBuilder(BuildContext)?, PdfDocument? docFallback}) → Widget
Open PDF using async function.
openFutureData(Future<Uint8List> getData(), {Key? key, PdfViewerController? viewerController, PdfViewerParams? params, OnError? onError, Widget loadingBannerBuilder(BuildContext)?, PdfDocument? docFallback}) → Widget
Open PDF data on byte array returned by async function.
openFutureFile(Future<String> getFilePath(), {Key? key, PdfViewerController? viewerController, PdfViewerParams? params, OnError? onError, Widget loadingBannerBuilder(BuildContext)?, PdfDocument? docFallback}) → Widget
Open PDF from the filename returned by async function.